var languageNames = {
"en-US": "Angielski (USA)",
"sq": "Albański",
"am": "Amharski",
"ar": "Arabski",
"ast": "Asturyjski",
"bn": "Bengalski",
"bn-IN": "Bengalski (Indie)",
"bs": "Bośniacki",
"bg": "Bułgarski",
"ca": "Kataloński",
"ca-valencia": "Walencki kataloński",
"zh-CN": "Chiński (uproszczony)",
"zh-TW": "Chiński (tradycyjny)",
"hr": "Chorwacki",
"cs": "Czeski",
"da": "Duński",
"nl": "Holenderski",
"dz": "Dzongkha",
"en-GB": "Angielski (UK)",
"en-ZA": "Angielski (RPA)",
"eo": "Esperanto",
"et": "Estoński",
"eu": "Baskijski",
"fi": "Fiński",
"fr": "Francuski",
"gl": "Galicyjski",
"ka": "Gruziński",
"de": "Niemiecki",
"el": "Grecki",
"gu": "Gudżarati",
"he": "Hebrajski",
"hi": "Hinduski",
"hu": "Węgierski",
"id": "Indonezyjski",
"is": "Islandzki",
"it": "Włoski",
"ja": "Japoński",
"km": "Khmerski",
"ko": "Koreański",
"lo": "Laotański",
"lv": "Łotewski",
"lt": "Litewski",
"mk": "Macedoński",
"ne": "Nepalski",
"nn": "Norweski (nynorsk)‎",
"nb": "Norweski (bokmål)",
"om": "Oromo",
"pl": "Polski",
"pt": "Portugalski",
"pt-BR": "Portugalski (Brazylia)",
"ro": "Rumuński",
"ru": "Rosyjski",
"sid": "Sidama",
"si": "Sinhala",
"sk": "Słowacki",
"sl": "Słoweński",
"dsb": "Łużycki (dolny)",
"hsb": "Łużycki (górny)",
"es": "Hszpański",
"sv": "Szwedzki",
"tg": "Tadżycki",
"ta": "Tamilski",
"bo": "Tybetański",
"tl": "Tagalog",
"tr": "Turecki",
"ug": "Ujgurski",
"uk": "Ukraiński",
"vi": "Wietnamski",
};
